Product class

Constructors

Product({int? id, String? title, String? bodyHtml, String? vendor, String? productType, DateTime? createdAt, String? handle, DateTime? updatedAt, DateTime? publishedAt, String? templateSuffix, String? status, String? publishedScope, String? tags, String? adminGraphqlApiId, List<Variants>? variants, List<Options>? options, List<Images>? images, Images? image})
Product.fromJson(Map<String, dynamic> json)

Properties

adminGraphqlApiId ↔ String?
getter/setter pair
bodyHtml ↔ String?
getter/setter pair
compareAtPrice → String
no setter
createdAt ↔ DateTime?
getter/setter pair
defaultVariant → Variants?
no setter
handle ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
image ↔ Images?
getter/setter pair
images ↔ List<Images>?
getter/setter pair
name → String
no setter
onSale → bool
no setter
options ↔ List<Options>?
getter/setter pair
price → String
no setter
productType ↔ String?
getter/setter pair
publishedAt ↔ DateTime?
getter/setter pair
publishedScope ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
getter/setter pair
tags ↔ String?
getter/setter pair
templateSuffix ↔ String?
getter/setter pair
title ↔ String?
getter/setter pair
updatedAt ↔ DateTime?
getter/setter pair
variants ↔ List<Variants>?
getter/setter pair
vendor ↔ String?
getter/setter pair

Methods

findVariation(Map<int, dynamic> options) → Variants?
findVariationImage(int? imageId) → String?
getOption(String name) → Options?
getOptionValues(String name) → List<String>?
hasVariations() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optionNameList() → List<String?>?
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited