Variants class

Constructors

Variants({int? id, int? productId, String? title, String? price, String? sku, int? position, String? inventoryPolicy, String? compareAtPrice, String? fulfillmentService, String? inventoryManagement, String? option1, String? option2, String? option3, DateTime? createdAt, DateTime? updatedAt, bool? taxable, String? barcode, double? grams, int? imageId, double? weight, String? weightUnit, int? inventoryItemId, int? inventoryQuantity, int? oldInventoryQuantity, bool? requiresShipping, String? adminGraphqlApiId})
Variants.fromJson(Map<String, dynamic> json)

Properties

adminGraphqlApiId ↔ String?
getter/setter pair
barcode ↔ String?
getter/setter pair
canPurchase → bool
no setter
compareAtPrice ↔ String?
getter/setter pair
createdAt ↔ DateTime?
getter/setter pair
fulfillmentService ↔ String?
getter/setter pair
grams ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
imageId ↔ int?
getter/setter pair
inventoryItemId ↔ int?
getter/setter pair
inventoryManagement ↔ String?
getter/setter pair
inventoryPolicy ↔ String?
getter/setter pair
inventoryQuantity ↔ int?
getter/setter pair
oldInventoryQuantity ↔ int?
getter/setter pair
option1 ↔ String?
getter/setter pair
option2 ↔ String?
getter/setter pair
option3 ↔ String?
getter/setter pair
position ↔ int?
getter/setter pair
price ↔ String?
getter/setter pair
productId ↔ int?
getter/setter pair
requiresShipping ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sku ↔ String?
getter/setter pair
taxable ↔ bool?
getter/setter pair
title ↔ String?
getter/setter pair
updatedAt ↔ DateTime?
getter/setter pair
weight ↔ double?
getter/setter pair
weightUnit ↔ String?
getter/setter pair

Methods

inStock() → bool
isOutOfStock() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited