ProductImage class

Constructors

ProductImage({int? id, int? productId, int? position, DateTime? createdAt, DateTime? updatedAt, String? alt, int? width, int? height, String? src, List<int>? variantIds, String? adminGraphqlApiId})
ProductImage.fromJson(Map<String, dynamic> json)

Properties

adminGraphqlApiId ↔ String?
getter/setter pair
alt ↔ String?
getter/setter pair
createdAt ↔ DateTime?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int?
getter/setter pair
id ↔ int?
getter/setter pair
position ↔ int?
getter/setter pair
productId ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src ↔ String?
getter/setter pair
updatedAt ↔ DateTime?
getter/setter pair
variantIds ↔ List<int>?
getter/setter pair
width ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited