AuthCustomerInfo class

The AuthCustomerInfo class holds the customer's information

Constructors

AuthCustomerInfo({String? email, String? firstName, String? lastName, String? id, String? uid, String? phone, DefaultAddress? defaultAddress})
AuthCustomerInfo.fromJson(dynamic json)

Properties

defaultAddress ↔ DefaultAddress?
getter/setter pair
email ↔ String?
getter/setter pair
firstName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
lastName ↔ String?
getter/setter pair
phone ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited