DefaultAddress class

Default address of the customer

Constructors

DefaultAddress({String? id, String? address1, String? city, String? country, String? province, String? provinceCode, String? phone, String? countryCode, String? zip})
DefaultAddress.fromJson(Map<String, dynamic> json)
Parses JSON data to DefaultAddress

Properties

address1 ↔ String?
getter/setter pair
city ↔ String?
getter/setter pair
country ↔ String?
getter/setter pair
countryCode ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
phone ↔ String?
getter/setter pair
province ↔ String?
getter/setter pair
provinceCode ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zip ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts the DefaultAddress to a map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited