AuthCustomer class

AuthCustomer Model.

Inheritance

Constructors

AuthCustomer({User? user, List<ShopifyError>? errors})
AuthCustomer.fromJson(Map<String, dynamic> json)

Properties

errors ↔ List<ShopifyError>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user ↔ User?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save({bool inBackpack = false}) → Future
Save the object to secure storage using a unique key. E.g. User class
inherited
saveToCollection({bool inBackpack = false}) → Future
Save an item to a collection.
inherited
syncToBackpack() → Future<bool>
Attempt to login a user using a storageKey.
inherited
toJson() → Map<String, dynamic>
Convert the model to a JSON map. Override this in subclasses.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited