Province class

Constructors

Province({int? id, int? countryId, String? name, String? code, TaxName? taxName, String? taxType, dynamic shippingZoneId, int? tax, int? taxPercentage})
Province.fromJson(Map<String, dynamic> json)
factory

Properties

code ↔ String?
getter/setter pair
countryId ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingZoneId ↔ dynamic
getter/setter pair
tax ↔ int?
getter/setter pair
taxName ↔ TaxName?
getter/setter pair
taxPercentage ↔ int?
getter/setter pair
taxType ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited