Customer class

Constructors

Customer({int? id, String? email, bool? acceptsMarketing, String? createdAt, String? updatedAt, String? firstName, String? lastName, int? ordersCount, String? state, String? totalSpent, String? note, bool? verifiedEmail, bool? taxExempt, String? phone, String? tags, String? currency, String? acceptsMarketingUpdatedAt, List<void>? taxExemptions})
Customer.fromJson(Map<String, dynamic> json)

Properties

acceptsMarketing ↔ bool?
getter/setter pair
acceptsMarketingUpdatedAt ↔ String?
getter/setter pair
createdAt ↔ String?
getter/setter pair
currency ↔ String?
getter/setter pair
email ↔ String?
getter/setter pair
firstName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
lastName ↔ String?
getter/setter pair
note ↔ String?
getter/setter pair
ordersCount ↔ int?
getter/setter pair
phone ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
getter/setter pair
tags ↔ String?
getter/setter pair
taxExempt ↔ bool?
getter/setter pair
taxExemptions ↔ List<void>?
getter/setter pair
totalSpent ↔ String?
getter/setter pair
updatedAt ↔ String?
getter/setter pair
verifiedEmail ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited