LineItems class

Constructors

LineItems({int? id, int? variantId, String? title, int? quantity, String? sku, String? variantTitle, String? vendor, String? fulfillmentService, int? productId, bool? requiresShipping, bool? taxable, bool? giftCard, String? name, String? variantInventoryManagement, List<void>? properties, bool? productExists, int? fulfillableQuantity, int? grams, String? price, String? totalDiscount, String? fulfillmentStatus, List<void>? discountAllocations, List<void>? duties, String? adminGraphqlApiId, List<void>? taxLines})
LineItems.fromJson(Map<String, dynamic> json)

Properties

adminGraphqlApiId ↔ String?
getter/setter pair
discountAllocations ↔ List<void>?
getter/setter pair
duties ↔ List<void>?
getter/setter pair
fulfillableQuantity ↔ int?
getter/setter pair
fulfillmentService ↔ String?
getter/setter pair
fulfillmentStatus ↔ String?
getter/setter pair
giftCard ↔ bool?
getter/setter pair
grams ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
name ↔ String?
getter/setter pair
price ↔ String?
getter/setter pair
productExists ↔ bool?
getter/setter pair
productId ↔ int?
getter/setter pair
properties ↔ List<void>?
getter/setter pair
quantity ↔ int?
getter/setter pair
requiresShipping ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sku ↔ String?
getter/setter pair
taxable ↔ bool?
getter/setter pair
taxLines ↔ List<void>?
getter/setter pair
title ↔ String?
getter/setter pair
totalDiscount ↔ String?
getter/setter pair
variantId ↔ int?
getter/setter pair
variantInventoryManagement ↔ String?
getter/setter pair
variantTitle ↔ String?
getter/setter pair
vendor ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited