Order class

Constructors

Order({int? id, String? email, String? closedAt, String? createdAt, String? updatedAt, int? number, String? note, String? token, String? gateway, bool? test, String? totalPrice, String? subtotalPrice, int? totalWeight, String? totalTax, bool? taxesIncluded, String? currency, String? financialStatus, bool? confirmed, String? totalDiscounts, String? totalLineItemsPrice, String? cartToken, bool? buyerAcceptsMarketing, String? name, String? referringSite, String? landingSite, String? totalPriceUsd, String? checkoutToken, int? userId, int? locationId, String? processedAt, String? phone, String? customerLocale, int? appId, int? orderNumber, List<void>? discountApplications, List<void>? discountCodes, List<void>? noteAttributes, String? processingMethod, int? checkoutId, String? sourceName, String? fulfillmentStatus, List<void>? taxLines, String? tags, String? contactEmail, String? orderStatusUrl, String? presentmentCurrency, List<LineItems>? lineItems, String? adminGraphqlApiId, List<void>? shippingLines, BillingAddress? billingAddress, BillingAddress? shippingAddress, Customer? customer})
Order.fromJson(Map<String, dynamic> json)

Properties

adminGraphqlApiId ↔ String?
getter/setter pair
appId ↔ int?
getter/setter pair
billingAddress ↔ BillingAddress?
getter/setter pair
buyerAcceptsMarketing ↔ bool?
getter/setter pair
cartToken ↔ String?
getter/setter pair
checkoutId ↔ int?
getter/setter pair
checkoutToken ↔ String?
getter/setter pair
closedAt ↔ String?
getter/setter pair
confirmed ↔ bool?
getter/setter pair
contactEmail ↔ String?
getter/setter pair
createdAt ↔ String?
getter/setter pair
currency ↔ String?
getter/setter pair
customer ↔ Customer?
getter/setter pair
customerLocale ↔ String?
getter/setter pair
discountApplications ↔ List<void>?
getter/setter pair
discountCodes ↔ List<void>?
getter/setter pair
email ↔ String?
getter/setter pair
financialStatus ↔ String?
getter/setter pair
fulfillmentStatus ↔ String?
getter/setter pair
gateway ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
landingSite ↔ String?
getter/setter pair
lineItems ↔ List<LineItems>?
getter/setter pair
locationId ↔ int?
getter/setter pair
name ↔ String?
getter/setter pair
note ↔ String?
getter/setter pair
noteAttributes ↔ List<void>?
getter/setter pair
number ↔ int?
getter/setter pair
orderNumber ↔ int?
getter/setter pair
orderStatusUrl ↔ String?
getter/setter pair
phone ↔ String?
getter/setter pair
presentmentCurrency ↔ String?
getter/setter pair
processedAt ↔ String?
getter/setter pair
processingMethod ↔ String?
getter/setter pair
referringSite ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingAddress ↔ BillingAddress?
getter/setter pair
shippingLines ↔ List<void>?
getter/setter pair
sourceName ↔ String?
getter/setter pair
subtotalPrice ↔ String?
getter/setter pair
tags ↔ String?
getter/setter pair
taxesIncluded ↔ bool?
getter/setter pair
taxLines ↔ List<void>?
getter/setter pair
test ↔ bool?
getter/setter pair
token ↔ String?
getter/setter pair
totalDiscounts ↔ String?
getter/setter pair
totalLineItemsPrice ↔ String?
getter/setter pair
totalPrice ↔ String?
getter/setter pair
totalPriceUsd ↔ String?
getter/setter pair
totalTax ↔ String?
getter/setter pair
totalWeight ↔ int?
getter/setter pair
updatedAt ↔ String?
getter/setter pair
userId ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited