LineItems class

Constructors

LineItems({String? id, Images? images, String? name, int? quantity, String? title, String? variantTitle, OriginalUnitPriceSet? originalUnitPriceSet, OriginalUnitPriceSet? originalTotalSet})
LineItems.fromJson(Map<String, dynamic> json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
images ↔ Images?
getter/setter pair
name ↔ String?
getter/setter pair
originalTotalSet ↔ OriginalUnitPriceSet?
getter/setter pair
originalUnitPriceSet ↔ OriginalUnitPriceSet?
getter/setter pair
quantity ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
getter/setter pair
variantTitle ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited