Variants class

Constructors

Variants({String? id, String? title, bool? taxable, String? sku, MaxVariantPrice? compareAtPrice, List<SelectedOptions>? selectedOptions, MaxVariantPrice? price, FeaturedImage? image})
Variants.fromJson(Map<String, dynamic> json)

Properties

compareAtPrice ↔ MaxVariantPrice?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
image ↔ FeaturedImage?
getter/setter pair
price ↔ MaxVariantPrice?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedOptions ↔ List<SelectedOptions>?
getter/setter pair
sku ↔ String?
getter/setter pair
taxable ↔ bool?
getter/setter pair
title ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited