Shop class

Constructors

Shop({int? id, String? name, String? email, String? domain, String? province, String? country, String? address1, String? zip, String? city, dynamic source, String? phone, double? latitude, double? longitude, String? primaryLocale, String? address2, DateTime? createdAt, DateTime? updatedAt, String? countryCode, String? countryName, String? currency, String? customerEmail, String? timezone, String? ianaTimezone, String? shopOwner, String? moneyFormat, String? moneyWithCurrencyFormat, String? weightUnit, String? provinceCode, bool? taxesIncluded, dynamic autoConfigureTaxInclusivity, dynamic taxShipping, bool? countyTaxes, String? planDisplayName, String? planName, bool? hasDiscounts, bool? hasGiftCards, String? myshopifyDomain, dynamic googleAppsDomain, dynamic googleAppsLoginEnabled, String? moneyInEmailsFormat, String? moneyWithCurrencyInEmailsFormat, bool? eligibleForPayments, bool? requiresExtraPaymentsAgreement, bool? passwordEnabled, bool? hasStorefront, bool? finances, int? primaryLocationId, String? cookieConsentLevel, bool? checkoutApiSupported, bool? multiLocationEnabled, bool? setupRequired, bool? preLaunchEnabled, List<String>? enabledPresentmentCurrencies, bool? transactionalSmsDisabled, bool? marketingSmsConsentEnabledAtCheckout})
Shop.fromJson(Map<String, dynamic> json)
factory

Properties

address1 ↔ String?
getter/setter pair
address2 ↔ String?
getter/setter pair
autoConfigureTaxInclusivity ↔ dynamic
getter/setter pair
checkoutApiSupported ↔ bool?
getter/setter pair
city ↔ String?
getter/setter pair
cookieConsentLevel ↔ String?
getter/setter pair
country ↔ String?
getter/setter pair
countryCode ↔ String?
getter/setter pair
countryName ↔ String?
getter/setter pair
countyTaxes ↔ bool?
getter/setter pair
createdAt ↔ DateTime?
getter/setter pair
currency ↔ String?
getter/setter pair
customerEmail ↔ String?
getter/setter pair
domain ↔ String?
getter/setter pair
eligibleForPayments ↔ bool?
getter/setter pair
email ↔ String?
getter/setter pair
enabledPresentmentCurrencies ↔ List<String>?
getter/setter pair
finances ↔ bool?
getter/setter pair
googleAppsDomain ↔ dynamic
getter/setter pair
googleAppsLoginEnabled ↔ dynamic
getter/setter pair
hasDiscounts ↔ bool?
getter/setter pair
hasGiftCards ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasStorefront ↔ bool?
getter/setter pair
ianaTimezone ↔ String?
getter/setter pair
id ↔ int?
getter/setter pair
latitude ↔ double?
getter/setter pair
longitude ↔ double?
getter/setter pair
marketingSmsConsentEnabledAtCheckout ↔ bool?
getter/setter pair
moneyFormat ↔ String?
getter/setter pair
moneyInEmailsFormat ↔ String?
getter/setter pair
moneyWithCurrencyFormat ↔ String?
getter/setter pair
moneyWithCurrencyInEmailsFormat ↔ String?
getter/setter pair
multiLocationEnabled ↔ bool?
getter/setter pair
myshopifyDomain ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
passwordEnabled ↔ bool?
getter/setter pair
phone ↔ String?
getter/setter pair
planDisplayName ↔ String?
getter/setter pair
planName ↔ String?
getter/setter pair
preLaunchEnabled ↔ bool?
getter/setter pair
primaryLocale ↔ String?
getter/setter pair
primaryLocationId ↔ int?
getter/setter pair
province ↔ String?
getter/setter pair
provinceCode ↔ String?
getter/setter pair
requiresExtraPaymentsAgreement ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setupRequired ↔ bool?
getter/setter pair
shopOwner ↔ String?
getter/setter pair
source ↔ dynamic
getter/setter pair
taxesIncluded ↔ bool?
getter/setter pair
taxShipping ↔ dynamic
getter/setter pair
timezone ↔ String?
getter/setter pair
transactionalSmsDisabled ↔ bool?
getter/setter pair
updatedAt ↔ DateTime?
getter/setter pair
weightUnit ↔ String?
getter/setter pair
zip ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited