SmartCollections class

Constructors

SmartCollections({int? id, String? handle, String? title, String? updatedAt, String? bodyHtml, String? publishedAt, String? sortOrder, String? templateSuffix, bool? disjunctive, List<Rules>? rules, String? publishedScope, String? adminGraphqlApiId})
SmartCollections.fromJson(Map<String, dynamic> json)

Properties

adminGraphqlApiId ↔ String?
getter/setter pair
bodyHtml ↔ String?
getter/setter pair
disjunctive ↔ bool?
getter/setter pair
handle ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
publishedAt ↔ String?
getter/setter pair
publishedScope ↔ String?
getter/setter pair
rules ↔ List<Rules>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortOrder ↔ String?
getter/setter pair
templateSuffix ↔ String?
getter/setter pair
title ↔ String?
getter/setter pair
updatedAt ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited