WooSignalApp class

Constructors

WooSignalApp({String? appName, String? appTermsLink, String? appPrivacyLink, int? appDebug, int? appStatus, CurrencyMeta? currencyMeta, List<String>? bannerImages, bool? stripeLiveMode, String? stripeAccount, int? wpLoginEnabled, String? wpLoginBaseUrl, String? wpLoginForgotPasswordUrl, String? wpLoginWpApiPath, int? productPricesIncludeTax, bool? disableShipping, String? theme, String? locale, String? paypalLocale, String? paypalEmail, bool? stripeEnabled, bool? codEnabled, bool? paypalEnabled, bool? paypalLiveMode, String? stripeCountryCode, bool? couponEnabled, bool? wishlistEnabled, String? themeFont, Map<String, dynamic>? socialLinks, List<MenuLink> menuLinks = const [], Map<String, dynamic>? themeColors, String? supportEmail, Map<String, dynamic>? firebaseOptionsIos = const {}, List<AppShopifyCollection> shopifyCollections = const [], Map<String, dynamic>? firebaseOptionsAndroid = const {}})
WooSignalApp.fromJson(Map<String, dynamic> json)

Properties

appDebug ↔ int?
getter/setter pair
getter/setter pair
appName ↔ String?
getter/setter pair
getter/setter pair
appStatus ↔ int?
getter/setter pair
getter/setter pair
bannerImages ↔ List<String>?
getter/setter pair
codEnabled ↔ bool?
getter/setter pair
couponEnabled ↔ bool?
getter/setter pair
currencyMeta ↔ CurrencyMeta?
getter/setter pair
disableShipping ↔ bool?
getter/setter pair
firebaseFcmIsEnabled ↔ bool?
getter/setter pair
firebaseOptionsAndroid ↔ Map<String, dynamic>?
getter/setter pair
firebaseOptionsIos ↔ Map<String, dynamic>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
locale ↔ String?
getter/setter pair
getter/setter pair
paypalEmail ↔ String?
getter/setter pair
paypalEnabled ↔ bool?
getter/setter pair
paypalLiveMode ↔ bool?
getter/setter pair
paypalLocale ↔ String?
getter/setter pair
productPricesIncludeTax ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopifyCollections ↔ List<AppShopifyCollection>
getter/setter pair
showProductReviews ↔ bool?
getter/setter pair
showRelatedProducts ↔ bool?
getter/setter pair
showUpsellProducts ↔ bool?
getter/setter pair
getter/setter pair
stripeAccount ↔ String?
getter/setter pair
stripeCountryCode ↔ String?
getter/setter pair
stripeEnabled ↔ bool?
getter/setter pair
stripeLiveMode ↔ bool?
getter/setter pair
supportEmail ↔ String?
getter/setter pair
taxesIncluded ↔ bool?
getter/setter pair
taxShipping ↔ bool?
getter/setter pair
theme ↔ String?
getter/setter pair
themeColors ↔ Map<String, dynamic>?
getter/setter pair
themeFont ↔ String?
getter/setter pair
wishlistEnabled ↔ bool?
getter/setter pair
wpLoginBaseUrl ↔ String?
getter/setter pair
wpLoginEnabled ↔ int?
getter/setter pair
wpLoginForgotPasswordUrl ↔ String?
getter/setter pair
wpLoginWpApiPath ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited