LineItems class

Constructors

LineItems({String? price, int? productId, int? quantity, bool? requiresShipping, String? sku, int? variantId, bool? taxable})
LineItems.fromJson(Map<String, dynamic> json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
price ↔ String?
getter/setter pair
productId ↔ int?
getter/setter pair
quantity ↔ int?
getter/setter pair
requiresShipping ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sku ↔ String?
getter/setter pair
taxable ↔ bool?
getter/setter pair
variantId ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited