ShippingLines class

Constructors

ShippingLines({String? code, String? price, String? source, String? title, List<TaxLines>? taxLines, String? carrierIdentifier, String? requestedFulfillmentServiceId})
ShippingLines.fromJson(Map<String, dynamic> json)

Properties

carrierIdentifier ↔ String?
getter/setter pair
code ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
price ↔ String?
getter/setter pair
requestedFulfillmentServiceId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ String?
getter/setter pair
taxLines ↔ List<TaxLines>?
getter/setter pair
title ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited