ShopifyOrder class

Constructors

ShopifyOrder({String? customer, BillingAddress? billingAddress, String? currency, List<DiscountCodes>? discountCodes, String? email, String? financialStatus, List<LineItems>? lineItems, String? presentmentCurrency, ShippingAddress? shippingAddress, List<ShippingLines>? shippingLines, bool? taxesIncluded, bool? test, String? totalDiscounts, String? totalLineItemsPrice, String? totalPrice, String? totalTax, List<TaxLines>? taxLines, bool? sendReceipt, bool? sendFulfillmentReceipt, List<Transaction>? transactions})
ShopifyOrder.fromJson(Map<String, dynamic> json)

Properties

billingAddress ↔ BillingAddress?
getter/setter pair
currency ↔ String?
getter/setter pair
customer ↔ String?
getter/setter pair
discountCodes ↔ List<DiscountCodes>?
getter/setter pair
email ↔ String?
getter/setter pair
financialStatus ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lineItems ↔ List<LineItems>?
getter/setter pair
presentmentCurrency ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendFulfillmentReceipt ↔ bool?
getter/setter pair
sendReceipt ↔ bool?
getter/setter pair
shippingAddress ↔ ShippingAddress?
getter/setter pair
shippingLines ↔ List<ShippingLines>?
getter/setter pair
taxesIncluded ↔ bool?
getter/setter pair
taxLines ↔ List<TaxLines>?
getter/setter pair
test ↔ bool?
getter/setter pair
totalDiscounts ↔ String?
getter/setter pair
totalLineItemsPrice ↔ String?
getter/setter pair
totalPrice ↔ String?
getter/setter pair
totalTax ↔ String?
getter/setter pair
transactions ↔ List<Transaction>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited