Transaction class

Constructors

Transaction({String? kind, String? status, String? amount, String? currency, String? gateway, bool? test})
Transaction.fromJson(Map<String, dynamic> json)

Properties

amount ↔ String?
getter/setter pair
currency ↔ String?
getter/setter pair
gateway ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
getter/setter pair
test ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited