Countries class

Constructors

Countries({int? id, String? name, double? tax, String? code, String? taxName, int? shippingZoneId, List<Provinces?> provinces = const []})
Countries.fromJson(Map<String, dynamic> json)

Properties

code ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
name ↔ String?
getter/setter pair
provinces ↔ List<Provinces?>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingZoneId ↔ int?
getter/setter pair
tax ↔ double?
getter/setter pair
taxName ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited